@@ -1,4 +1,4 @@
-# Copyright (c) 2013, 2018, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2013, 2020, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0,
@@ -28,6 +28,7 @@ from workbench.graphics.canvas import ImageFigure
 from wb_admin_perfschema_instrumentation_be import PSConfiguration, PSTimerType, PSObject, PSActor
 
 from workbench.log import log_info, log_error
+from workbench.notifications import nc
 
 from wb_admin_perfschema import WbAdminPSBaseTab
 
@@ -72,8 +73,8 @@ class BigSwitch(mforms.PyDrawBox):
         self.hovering_state = None
         self.mouse_pos = None, None
 
-        self.text_image = ImageFigure(mforms.App.get().get_resource_path("ps_switcher_text.png"))
-        self.legend = ImageFigure(mforms.App.get().get_resource_path("ps_switcher_legende.png"))
+        self.updateImage()
+        self.legend = ImageFigure(mforms.App.get().get_resource_path("ps_switcher_legend.png"))
 
         self.state_images = []
         for item in ["fully", "custom", "default", "disabled"]:
@@ -94,7 +95,7 @@ class BigSwitch(mforms.PyDrawBox):
             xx = (self.get_width() - image.width - self.text_image.width) / 2
             if state == self.state:
                 image = on
-            else:
+            elif self.mouse_pos[0] and self.mouse_pos[1]:
                 if self.mouse_pos[0] > xx and self.mouse_pos[0] < xx + image.width and self.mouse_pos[1] >= yy and self.mouse_pos[1] <= yy + image.height and state != "custom":
                     image = hoover
                     self.hovering_state = state
@@ -110,7 +111,6 @@ class BigSwitch(mforms.PyDrawBox):
         self.legend.render(c)
 
 
-
     def set_state(self, state):
         self.state = state
         self.set_needs_repaint()
@@ -125,6 +125,12 @@ class BigSwitch(mforms.PyDrawBox):
         if self.hovering_state:
             self.callback(self.hovering_state)
 
+    def updateImage(self):
+        if mforms.App.get().isDarkModeActive():
+            self.text_image = ImageFigure(mforms.App.get().get_resource_path("ps_switcher_text_dark.png"))
+        else:
+            self.text_image = ImageFigure(mforms.App.get().get_resource_path("ps_switcher_text_light.png"))
+
 
 class EasySetupPage(mforms.Box):
     def __init__(self, owner):
@@ -132,9 +138,10 @@ class EasySetupPage(mforms.Box):
         self.set_managed()
         self.set_release_on_add()
         self.set_spacing(12)
-        self.set_padding(12)
+        self.set_padding(20)
         self.owner = owner
 
+        nc.add_observer(self.updateColors, "GNColorsChanged")
         self.create_ui()
 
 
@@ -192,7 +199,7 @@ class EasySetupPage(mforms.Box):
 
             return "custom"
 
-        except grt.DBError, e:
+        except grt.DBError as e:
             log_error("MySQL error querying PS instrumentation/consumers: %s\n" % e)
             mforms.Utilities.show_error("Check Performance Schema Configuration State", "Error checking configuration state of Performance Schema: %s" % e, "OK", "", "")
 
@@ -244,7 +251,7 @@ class EasySetupPage(mforms.Box):
                     consumers = DEFAULT_CONSUMERS_56
                 mforms.App.get().set_status_text("Resetting Performance Schema settings to default instrumentation...")
                 sql = self.generate_updates_for_reset(instruments, consumers)
-                print sql
+                print(sql)
             for s in sql:
                 log_info("Executing %s...\n" % s)
                 self.owner.main_view.editor.executeManagementCommand(s, 0)
@@ -254,7 +261,7 @@ class EasySetupPage(mforms.Box):
                 mforms.App.get().set_status_text("Disabled Performance Schema Settings")
 
             self.owner.rebuild_ui(False)
-        except grt.DBError, e:
+        except grt.DBError as e:
             log_error("MySQL error toggling (%s) PS Instrumentation\n" % e)
             mforms.App.get().set_status_text("Error toggling Performance Schema Instrumentation: %s" % e)
             mforms.Utilities.show_error("Toggle Performance Schema Instrumentation",
@@ -268,9 +275,14 @@ class EasySetupPage(mforms.Box):
         self.logo.set_image(mforms.App.get().get_resource_path("ps_easysetup_logo.png"))
         self.add(self.logo, False, True)
 
+        label = mforms.newLabel("Performance Schema")
+        label.set_text_align(mforms.MiddleCenter)
+        label.set_style(mforms.VeryBigStyle)
+        self.add(label, False, True)
+
         self.switch_image = BigSwitch()
         self.switch_image.callback = self.change_instrumentation
-        self.switch_image.set_size(200, 152)
+        self.switch_image.set_size(105, 140)
         self.add(self.switch_image, False, True)
 
         image = mforms.newImageBox()
@@ -284,10 +296,12 @@ class EasySetupPage(mforms.Box):
 
     def reload(self):
         state = self.check_instrumentation_level()
-        print state
+        print(state)
         self.logo.set_image(mforms.App.get().get_resource_path("ps_easysetup_logo_enabled.png" if state != "disabled" else "ps_easysetup_logo.png"))
         self.switch_image.set_state(state)
 
+    def updateColors(self, name, sender, info):
+        self.switch_image.updateImage()
 
 class SetupInstruments(mforms.Box):
     def __init__(self, owner, data):
@@ -337,7 +351,7 @@ The timed column indicates whether information about the event duration is recor
         """
         changes = self._data.get_changes()
 
-        for item in changes.keys():
+        for item in list(changes.keys()):
             tokens = item.split('/')
             node = self._instruments.root_node()
             for token in tokens:
@@ -365,7 +379,7 @@ The timed column indicates whether information about the event duration is recor
         Inserts nodes based on the model which is an instance
         of PSInstrumentGroup.
         """
-        for child in model.keys():
+        for child in list(model.keys()):
             node = None
             tag = child
             if parent:
@@ -387,7 +401,7 @@ The timed column indicates whether information about the event duration is recor
             self.tag_models[tag] = model[child]
 
             # Inserts children
-            if not model[child].has_key('_data_'):
+            if '_data_' not in model[child]:
                 self.insert_nodes(model[child], node)
 
 
@@ -455,7 +469,7 @@ class SetupDataCollection(mforms.Box):
         self._data[name].enabled = is_active
 
         # Enables/disables child controls based on paren's status
-        if self._child_controls.has_key(caller):
+        if caller in self._child_controls:
             for child in self._child_controls[caller]:
                 child.set_enabled(is_active)
 
@@ -478,7 +492,7 @@ class SetupDataCollection(mforms.Box):
 
         # If the control has a parent, adds the relation
         if parent:
-            if not self._child_controls.has_key(parent):
+            if parent not in self._child_controls:
                 self._child_controls[parent] = []
             
             self._child_controls[parent].append(checkbox)
@@ -640,18 +654,18 @@ class SetupDataCollection(mforms.Box):
         """
         changes = self._data.get_changes()
 
-        for item in changes.keys():
+        for item in list(changes.keys()):
             # There's only one possible change
             (att, old, new) = changes[item][0]
 
             # This validation is needed cuz not all the consumers
             # have a checkbox on this screen
-            if self._controls.has_key(item):
+            if item in self._controls:
                 item_ctrl = self._controls[item]
 
                 item_ctrl.set_active(bool(old))
 
-                if self._child_controls.has_key(item_ctrl):
+                if item_ctrl in self._child_controls:
                     for control in self._child_controls[item_ctrl]:
                         control.set_enabled(bool(old))
     
@@ -1090,7 +1104,7 @@ class SetupOptions(mforms.Box):
 
         self.owner = owner
         self._timers = timers
-        self._timer_names = self._timers.keys()
+        self._timer_names = list(self._timers.keys())
         self._timer_names.sort()
 
         self._controls = {}
@@ -1114,9 +1128,10 @@ class SetupOptions(mforms.Box):
         return "%ss        (%s)" % (timer.name.lower().capitalize(), description)
     
     def create_timer_row(self, table, offset):
-        table.add(mforms.newLabel("%s Events" % (self._timer_names[offset].capitalize()), True), 0, 1, offset, offset + 1, mforms.HFillFlag)
+        table.add(mforms.newLabel("%s Events" % (self._timer_names[offset].capitalize()), True), 0, 1, offset, offset + 1, mforms.HFillFlag | mforms.VFillFlag)
 
         selector = mforms.newSelector(mforms.SelectorPopup)
+        selector.set_name("Timer Option Selector")
         selector.add_items([self.get_timer_type_text(timer) for timer in self._timer_types])
 
         timer_name = self._timer_names[offset]
@@ -1129,7 +1144,7 @@ class SetupOptions(mforms.Box):
 
         self._controls[timer_name] = selector
 
-        table.add(selector, 1, 2, offset, offset + 1, mforms.VFillFlag|mforms.HFillFlag|mforms.HExpandFlag)
+        table.add(selector, 1, 2, offset, offset + 1, mforms.VFillFlag | mforms.HFillFlag | mforms.HExpandFlag)
 
         
     def create_ui(self):
@@ -1148,9 +1163,10 @@ class SetupOptions(mforms.Box):
                       "     - Overhead: Minimal number of cycles of overhead to obtain one timing.\n"\
                       "\n"\
                       "Here you can configure which timer will be used for each instrument type.\n\n"
-        vbox.add(mforms.newLabel(description), False, False)
+        vbox.add(mforms.newLabel(description), False, True)
 
         table = mforms.newTable()
+        table.set_name("Timer Options Table")
         table.set_padding(1)
         table.set_row_count(5)
         table.set_column_count(2)
@@ -1325,7 +1341,7 @@ class SetupThreads(mforms.Box):
         """
         self.threads.clear()
 
-        items = self._threads.keys()
+        items = list(self._threads.keys())
         items.sort()
         for item in items:
             node = self.threads.add_node()
@@ -1375,7 +1391,7 @@ class WbAdminPerformanceSchemaInstrumentation(WbAdminPSBaseTab, ChangeCounter):
 
     @classmethod
     def wba_register(cls, admin_context):
-        admin_context.register_page(cls, "wba_performance", "Performance Schema Setup", False)
+        admin_context.register_page(cls, "Performance", "Performance Schema Setup", "Performance Schema Setup", False)
     
     @classmethod
     def identifier(cls):
@@ -1562,7 +1578,7 @@ class WbAdminPerformanceSchemaInstrumentation(WbAdminPSBaseTab, ChangeCounter):
                                          "Clear Tables", "Cancel", "") == mforms.ResultOk:
             try:
                 self.main_view.editor.executeManagementCommand('call sys.ps_truncate_all_tables(0)', 1)
-            except Exception, e:
+            except Exception as e:
                 log_error("Error calling sys.ps_truncate_all_tables(0): %s\n" % e)
                 mforms.Utilities.show_error("Clear Event Tables", "An error occurred truncating performance_schema event tables.\n%s"%e, "OK", "", "")
 
@@ -1572,7 +1588,7 @@ class WbAdminPerformanceSchemaInstrumentation(WbAdminPSBaseTab, ChangeCounter):
                                          "Reset", "Cancel", "") == mforms.ResultOk:
             try:
                 self.main_view.editor.executeManagementCommand('call sys.ps_setup_reset_to_default(0)', 1)
-            except Exception, e:
+            except Exception as e:
                 log_error("Error calling sys.ps_reset_to_default(0): %s\n" % e)
                 mforms.Utilities.show_error("Reset Performance Schema Settings", "An error occurred resetting performance_schema instrumentation settings.\n%s"%e, "OK", "", "")
                 return
